*************************************************************************************************************
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
*			                               Replication file for:     		           	        	        *
*     				  "Congruence, National Context and Trust in European Institutions"   					*
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
*																						 	  				*			
* Author: 			Mariano Torcal and Pablo Christmann       						                     	*
* Contact: 			mariano.torcal@upf.edu, pablo.christmann@gesis.org                     					*
* Date: 			22nd of October 2018 	                                                     			*
* Version:			Stata 15.1                                                              				*                                                                          
* Dataset:          Eurobarometer.dta                                                						*		
* Logfile: 			Eurobarometer.txt													 					*
*																											*
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
*************************************************************************************************************

set more off
clear all

*** Install required packages
ssc install outreg2
ssc install norm

*** Set directory to the location where replication files have been saved, for example:
cd "C:\Replication Materials JEPP"

*** Opening log
capture log close _all
log using Eurobarometer.log, name(Eurobarometer) replace 

*** Load Eurobarometer Trend Data. Compare Table A in the Online Appendix.
use "Eurobarometer.dta", clear

**************************
*** Drop missing cases ***
**************************
*** Trust
drop if trust_EU_Comm==.
drop if trust_government==.
drop if trust_EU_Parl==.
drop if trust_parliament==.

*** Individual-level covariates
drop if age==.
drop if male==.
drop if education==.
drop if married==.
drop if unemployed==.
drop if poldiscuss==.
drop if urban==.
drop if support_euro==.

*** Aggregate-level covariates
drop if unemployment_rate==.
drop if inflation_rate==.
drop if budget_deficit==.
drop if gpd_growht==.
drop if corruption==.
drop if EU_budget_balance==.

************************
*** Generate Indices ***
************************
*** Generate Economic Performance Index (EPI). Compare the Online Appendix for technical description.
/*
*** To obtain the correct std. dev. for the calculation of the index, please run the following syntax: 
bysort quarter: gen counter_n= _n
keep if counter_n==1
sum inflation_rate // Std. Dev.: 1.427295,
sum unemployment_rate  // Std. Dev.: 6.70195
sum budget_deficit // Std. Dev.: 4.405892 
sum gpd_growht // Std. Dev.: 2.363823
*/
gen EPI = 100 - abs(inflation_rate) - (unemployment_rate-4.75) + budget_deficit + (gpd_growht-4.75)
gen stdevav = (1.427295 + 6.70195 + 4.405892 + 2.363823) / 4
gen W_infl = (1/1.427295)* stdevav
gen W_unemp = (1/6.70195)* stdevav
gen W_deficit = (1/4.405892)* stdevav
gen W_growth = (1/2.363823)* stdevav
gen EPI_weighted = 100 - (W_infl*abs(inflation)) - (W_unemp*(unemployment-4.75)) + (budget_deficit*W_deficit) + (W_growth*(gpd_growht-4.75))

*** Generate tust in representative institutions of the EU index
gen trust_EU_rep = .
replace trust_EU_rep = 1 if trust_EU_Comm==1 & trust_EU_Parl==1
replace trust_EU_rep = 0 if trust_EU_Comm==0 & trust_EU_Parl==1
replace trust_EU_rep = 0 if trust_EU_Comm==1 & trust_EU_Parl==0
replace trust_EU_rep = 0 if trust_EU_Comm==0 & trust_EU_Parl==0
tab trust_EU_rep

*** Generate tust in representative institutions (Spain) index 
gen trust_rep = 0
replace trust_rep = 1 if trust_government==1 & trust_parliament==1
tab trust_rep

************************************
* Descriptive Statistics           *
************************************
/*
*** To obtain the descriptive statistics presented in Table B in the Online Appendix, please run the following syntax:
sum age
sum male
sum b1.education
sum b2.education
sum unemployed
sum urban
sum b1.poldiscuss
sum b2.poldiscuss
sum married
sum support_euro
sum trust_rep
sum trust_EU_rep

bysort quarter: gen counter_n= _n
keep if counter_n==1
sum EPI_weighted
sum inflation_rate
sum unemployment_rate
sum budget_deficit
sum gpd_growht
sum EU_election_year
sum corruption
sum EU_budget_balance
*/

**********************************************
*** Standardization of Continous Variables ***
**********************************************
*** Note: All standardized variables have the prefix zee_ 
norm age, method(zee)
norm poldiscuss, method(zee)
norm EPI_weighted, method(zee)
norm corruption, method(zee)
norm EU_budget_balance, method(zee)

******************************************************
*** Multivariate Analysis (Table 1)                ***
******************************************************
*** Null 1
meprobit trust_EU_rep  ||  month: , covariance(unstructured)
outreg2 using "Table_1.ster", replace ctitle(NULL) dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
outreg2 using "Table_1.xls",  excel replace  ctitle(NULL1)  dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
estat ic
estat icc

*** Model 1 
meprobit trust_EU_rep zee_age male b3.education married i.unemployed  i.urban i.poldiscuss i.trust_rep i.support_euro zee_EPI_weighted zee_corruption  zee_EU_budget_balance i.EU_election_year ||  month: , covariance(unstructured)
outreg2 using "Table_1.ster", append ctitle(Model 2) dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
outreg2 using "Table_1.xls",  excel append  ctitle(Model 2)  dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
estat ic
estat icc


*** Model 2 
meprobit trust_EU_rep zee_age male b3.education married i.unemployed  i.urban i.poldiscuss i.trust_rep i.support_euro zee_EPI_weighted zee_corruption  zee_EU_budget_balance i.EU_election_year ||  month: trust_rep , covariance(unstructured)
outreg2 using "Table_1.ster", append ctitle(Model 2) dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
outreg2 using "Table_1.xls",  excel append  ctitle(Model 2)  dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
estat ic
estat icc

*** Model 3 
meprobit trust_EU_rep zee_age male b3.education married i.unemployed  i.urban i.poldiscuss i.support_euro i.trust_rep##c.zee_EPI_weighted c.zee_corruption zee_EU_budget_balance i.EU_election_year ||  month: trust_rep , covariance(unstructured)
outreg2 using "Table_1.ster", append ctitle(Model 2) dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
outreg2 using "Table_1.xls",  excel append  ctitle(Model 2)  dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
estat ic
estat icc

*** Model 4 
meprobit trust_EU_rep zee_age male b3.education married i.unemployed  i.urban i.poldiscuss i.support_euro c.zee_EPI_weighted i.trust_rep##c.zee_corruption zee_EU_budget_balance i.EU_election_year ||  month: trust_rep , covariance(unstructured)
outreg2 using "Table_1.ster", append ctitle(Model 2) dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
outreg2 using "Table_1.xls",  excel append  ctitle(Model 2)  dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
estat ic
estat icc

*** Model 5 
meprobit trust_EU_rep zee_age male b3.education married i.unemployed  i.urban i.poldiscuss i.support_euro i.trust_rep##c.zee_EPI_weighted i.trust_rep##c.zee_corruption zee_EU_budget_balance i.EU_election_year ||  month: trust_rep  , covariance(unstructured)
outreg2 using "Table_1.ster", append ctitle(Model 2) dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
outreg2 using "Table_1.xls",  excel append  ctitle(Model 2)  dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
estat ic
estat icc

**************************************************************************************
*** Marginal Effects Plots for Cross-Level Interaction (Figure I in the Appendix)  ***
**************************************************************************************

*** Notes: For better interpretation the marginal effects plots are based on unstandardized coefficients for government fractionalization.
***        Figure X in the Online Appendix has been formatted with the Graph Editor afterwards. 

*** Model 5: Individual Level + Contextual Level + Cross-Level Interaction
meprobit trust_EU_rep age male b3.education married i.unemployed  i.urban i.poldiscuss i.support_euro i.trust_rep##c.EPI_weighted i.trust_rep##c.corruption EU_budget_balance i.EU_election_year ||  month: trust_rep , covariance(unstructured)

margins, dydx(trust_rep) at(EPI_weighted=(60 (5) 90)) predict(pr fixedonly) atmeans noatlegend vsquish
marginsplot, recast(line) recastci(rarea) yline(0)
graph save "Figure Ia.gph", replace
graph export "Figure Ia.tif", as(tif) width(2550) replace 

margins, dydx(trust_rep) at(corruption=(0 (5) 55)) predict(pr fixedonly) atmeans noatlegend vsquish
marginsplot, recast(line) recastci(rarea) yline(0)
graph save "Figure Ib.gph", replace
graph export "Figure Ib.tif", as(tif) width(2550) replace 

***************************************************************************
*** Predicted Change in Probabilities (Figure H in the Online Appendix) ***
***************************************************************************
*** Model 1 (unstandardized coefficients)
meprobit trust_EU_rep age male b3.education married i.unemployed  i.urban i.poldiscuss i.support_euro i.trust_rep c.EPI_weighted c.corruption EU_budget_balance i.EU_election_year ||  month:  , covariance(unstructured)

* Change in Probabilities from Min to Max
margins, at(age=(15 99)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish
margins, at(male=(0 1)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish
margins, at(education=(3 1)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish
margins, at(education=(3 2)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish
margins, at(education=(3 4)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish
margins, at(married=(0 1)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish
margins, at(urban=(0 1)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish
margins, at(unemployed=(0 1)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish
margins, at(poldiscuss=(0 1)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish
margins, at(poldiscuss=(0 2)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish
margins, at(support_euro=(0 1)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish
margins, at(trust_rep=(0 1)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish
margins, at(EPI_weighted=(59.17618 92.25895)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish
margins, at(corruption=(.47 55.37)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish
margins, at(EU_budget_balance=(1090.6 8859.4)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish
margins, at(EU_election_year=(0 1)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish

* Gen Matrix for coefplot
matrix trust_EP = (.1115053,.0608668,.1621439 \-.0194002,-.0360433,-.0027572\-.0652479,-.0900583,-.0404375\-.027214, -.0498123,-.0046158\.0150055,-.0198554,.0498664\.008731,-.0095781,.0270401\-.0211425,-.0415398,-.0007451\-.0356065,-.0616778,-.0095353\.0566981,.0380525,.0753438\.0352392,.0099041,.0605743\.3405939,.3230993,.3580885\.4203118,.4027688,.437854\.2568317,.1493734,.36429\-.3636752,-.4580734,-.2692769\-.0251659,-.1406673,.0903354\-.0100641,-.0830844,.0629562)
matrix rownames trust_EP = "Age" "Male" "Education (up to 15)" "Education (16-19)" "Education (Still studying)" "Married/ cohabitating" "Urban residency" "Unemployed" "Pol. discussion (occasionally)" "Pol. discussion (frequently)" "Support for Euro/ Monetary Union" "Trust in Rep. Institutions (Spain)" "Economic Performance Index (EPI)" "Perception of corruption" "EU Operating budgetary balances" "European election"
matrix dir 
matrix list trust_EP
coefplot (matrix(trust_EP[,1]), ci((trust_EP[,2] trust_EP[,3]))), xline(0) 
graph save "Figure H.gph", replace
graph export "Figure H.tif", as(tif) width(2550) replace 


************************************
////////////////////////////////////
////////////////////////////////////
*** Additional Robustness Checks ***
////////////////////////////////////
////////////////////////////////////
************************************

**************************************************************
//////////////////////////////////////////////////////////////
*** Trust in EU Parliament (Table C in the Online Appendix ***
//////////////////////////////////////////////////////////////
**************************************************************

*** Load Eurobarometer Trend Data. Compare Table A in the Online Appendix.
use "Eurobarometer.dta", clear

*** Trust
drop if trust_EU_Parl==.
drop if trust_parliament==.

*** Individual-level covariates
drop if age==.
drop if male==.
drop if education==.
drop if married==.
drop if unemployed==.
drop if poldiscuss==.
drop if urban==.
drop if support_euro==.

*** Aggregate-level covariates
drop if unemployment_rate==.
drop if inflation_rate==.
drop if budget_deficit==.
drop if gpd_growht==.
drop if corruption==.
drop if EU_budget_balance==.

************************
*** Generate Indices ***
************************
*** Generate Economic Performance Index (EPI). Compare the Online Appendix for technical description.
/*
*** To obtain the correct std. dev. for the calculation of the index, please run the following syntax: 
bysort quarter: gen counter_n= _n
keep if counter_n==1
sum inflation_rate // Std. Dev.: 1.431983
sum unemployment_rate  // Std. Dev.: 6.633627
sum budget_deficit // Std. Dev.: 4.349429
sum gpd_growht // Std. Dev.: 2.396575
*/
gen EPI = 100 - abs(inflation_rate) - (unemployment_rate-4.75) + budget_deficit + (gpd_growht-4.75)
gen stdevav = ( 1.431983   + 6.633627  +  4.349429 + 2.396575) / 4
gen W_infl = (1/ 1.431983)* stdevav
gen W_unemp = (1/6.633627)* stdevav
gen W_deficit = (1/4.349429)* stdevav
gen W_growth = (1/2.396575)* stdevav
gen EPI_weighted = 100 - (W_infl*abs(inflation)) - (W_unemp*(unemployment-4.75)) + (budget_deficit*W_deficit) + (W_growth*(gpd_growht-4.75))

**********************************************
*** Standardization of Continous Variables ***
**********************************************
*** Note: All standardized variables have the prefix zee_ 
norm age, method(zee)
norm poldiscuss, method(zee)
norm EPI_weighted, method(zee)
norm corruption, method(zee)
norm EU_budget_balance, method(zee)

**************************************************************
*** Multivariate Analysis (Table C in the Online Appendix) ***
**************************************************************
*** Null 4
meprobit trust_EU_Parl  ||  month: , covariance(unstructured)
outreg2 using "Table_C.ster", replace ctitle(NULL) dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
outreg2 using "Table_C.xls",  excel replace  ctitle(NULL1)  dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
estat ic
estat icc

*** Model 7 
meprobit trust_EU_Parl zee_age male b3.education married i.unemployed  i.urban i.poldiscuss i.trust_parliament i.support_euro zee_EPI_weighted zee_corruption  zee_EU_budget_balance i.EU_election_year ||  month: , covariance(unstructured)
outreg2 using "Table_C.ster", append ctitle(Model 2) dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
outreg2 using "Table_C.xls",  excel append  ctitle(Model 2)  dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
estat ic
estat icc

*** Model 8 
meprobit trust_EU_Parl zee_age male b3.education married i.unemployed  i.urban i.poldiscuss i.trust_parliament i.support_euro zee_EPI_weighted zee_corruption  zee_EU_budget_balance i.EU_election_year ||  month: trust_parliament , covariance(unstructured)
outreg2 using "Table_C.ster", append ctitle(Model 2) dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
outreg2 using "Table_C.xls",  excel append  ctitle(Model 2)  dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
estat ic
estat icc

*** Model 9 
meprobit trust_EU_Parl zee_age male b3.education married i.unemployed  i.urban i.poldiscuss i.support_euro i.trust_parliament##c.zee_EPI_weighted c.zee_corruption zee_EU_budget_balance i.EU_election_year ||  month: trust_parliament , covariance(unstructured)
outreg2 using "Table_C.ster", append ctitle(Model 2) dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
outreg2 using "Table_C.xls",  excel append  ctitle(Model 2)  dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
estat ic
estat icc

*** Model 10 
meprobit trust_EU_Parl zee_age male b3.education married i.unemployed  i.urban i.poldiscuss i.support_euro c.zee_EPI_weighted i.trust_parliament##c.zee_corruption zee_EU_budget_balance i.EU_election_year ||  month: trust_parliament , covariance(unstructured)
outreg2 using "Table_C.ster", append ctitle(Model 2) dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
outreg2 using "Table_C.xls",  excel append  ctitle(Model 2)  dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
estat ic
estat icc

*** Model 11
meprobit trust_EU_Parl zee_age male b3.education married i.unemployed  i.urban i.poldiscuss i.support_euro i.trust_parliament##c.zee_EPI_weighted i.trust_parliament##c.zee_corruption zee_EU_budget_balance i.EU_election_year ||  month: trust_parliament  , covariance(unstructured)
outreg2 using "Table_C.ster", append ctitle(Model 2) dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
outreg2 using "Table_C.xls",  excel append  ctitle(Model 2)  dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
estat ic
estat icc

*************************
*** Marginal Effects  ***
*************************
*** Notes: For better interpretation the marginal effects plots are based on unstandardized coefficients for government fractionalization.

*** Model 11: Individual Level + Contextual Level + Cross-Level Interaction (unstandardized coefficients)
meprobit trust_EU_Parl age male b3.education married i.unemployed  i.urban i.poldiscuss i.support_euro i.trust_parliament##c.EPI_weighted i.trust_parliament##c.corruption EU_budget_balance i.EU_election_year ||  month: trust_parliament , covariance(unstructured)

margins, dydx(trust_parliament) at(EPI_weighted=(60 (5) 90)) predict(pr fixedonly) atmeans noatlegend vsquish
marginsplot, recast(line) recastci(rarea) yline(0)

margins, dydx(trust_parliament) at(corruption=(0 (5) 55)) predict(pr fixedonly) atmeans noatlegend vsquish
marginsplot, recast(line) recastci(rarea) yline(0)

********************************
*** Predicted Probabilities  ***
******************************** 
*** Model 7 (unstandardized coefficients)  
meprobit trust_EU_Parl age male b3.education married i.unemployed  i.urban i.poldiscuss i.support_euro i.trust_parliament c.EPI_weighted c.corruption EU_budget_balance i.EU_election_year ||  month:  , covariance(unstructured)

* Change in Probabilities from Min to Max
margins, at(age=(15 99)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish
margins, at(male=(0 1)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish
margins, at(education=(3 1)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish
margins, at(education=(3 2)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish
margins, at(education=(3 4)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish
margins, at(married=(0 1)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish
margins, at(urban=(0 1)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish
margins, at(unemployed=(0 1)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish
margins, at(poldiscuss=(0 1)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish
margins, at(poldiscuss=(0 2)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish
margins, at(support_euro=(0 1)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish
margins, at(trust_parliament=(0 1)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish
margins, at(EPI_weighted=(59.17618 92.25895)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish
margins, at(corruption=(.47 55.37)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish
margins, at(EU_budget_balance=(1090.6 8859.4)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish
margins, at(EU_election_year=(0 1)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish

* Gen Matrix for coefplot // need to keep this for the final coeffplot combining trust in EP and trust in the EC
matrix trust_EP = (.0880994,.040682,.1355168 \-.0211231,-.0368128,-.0054334\-.0552405,-.078875,-.0316061\-.0168693,-.0382711,.0045325\.0285072,-.0036943,.0607087\.0060859,-.0111368,.0233085\.0011088,-.0181781,.0203957\-.0334208,-.0582759,-.0085656\.058578,.0410239,.0761321\.0350908,.010981,.0592007\.3369398,.3197419,.3541377\.4235318,.4060697,.4409939\.,.,.\.24364,.1299802,.3572997\-.3519817,-.4596285,-.2443349\.0245304,-.0937809,.1428417\.0040279,-.0707455,.0788013)
matrix rownames trust_EP = "Age" "Male" "Education (up to 15)" "Education (16-19)" "Education (Still studying)" "Married/ cohabitating" "Urban residency" "Unemployed" "Pol. discussion (occasionally)" "Pol. discussion (frequently)" "Support for Euro/ Monetary Union" "Trust in Spanish parliament" "Trust in Spanish government" "Economic Performance Index (EPI)" "Perception of corruption" "EU Operating budgetary balances" "European election"
matrix dir 
matrix list trust_EP
coefplot (matrix(trust_EP[,1]), ci((trust_EP[,2] trust_EP[,3]))), xline(0) 

**************************************************************
//////////////////////////////////////////////////////////////
*** Trust in EU Commission (Table D in the Online Appendix ***
//////////////////////////////////////////////////////////////
**************************************************************

*** Load Eurobarometer Trend Data. Compare Table A in the Online Appendix.
use "Eurobarometer.dta", clear

*** Trust
drop if trust_EU_Comm==.
drop if trust_government==.

*** Individual-level covariates
drop if age==.
drop if male==.
drop if education==.
drop if married==.
drop if unemployed==.
drop if poldiscuss==.
drop if urban==.
drop if support_euro==.

*** Aggregate-level covariates
drop if unemployment_rate==.
drop if inflation_rate==.
drop if budget_deficit==.
drop if gpd_growht==.
drop if corruption==.
drop if EU_budget_balance==.

************************
*** Generate Indices ***
************************
*** Generate Economic Performance Index (EPI). Compare the Online Appendix for technical description.
/*
*** To obtain the correct std. dev. for the calculation of the index, please run the following syntax: 
bysort quarter: gen counter_n= _n
keep if counter_n==1
sum inflation_rate // Std. Dev.: 1.427295,
sum unemployment_rate  // Std. Dev.: 6.70195
sum budget_deficit // Std. Dev.: 4.405892 
sum gpd_growht // Std. Dev.: 2.363823
*/

gen EPI = 100 - abs(inflation_rate) - (unemployment_rate-4.75) + budget_deficit + (gpd_growht-4.75)
gen stdevav = (1.427295   + 6.70195  + 4.405892 + 2.363823) / 4
gen W_infl = (1/1.427295)* stdevav
gen W_unemp = (1/6.70195)* stdevav
gen W_deficit = (1/4.405892)* stdevav
gen W_growth = (1/2.363823)* stdevav
gen EPI_weighted = 100 - (W_infl*abs(inflation)) - (W_unemp*(unemployment-4.75)) + (budget_deficit*W_deficit) + (W_growth*(gpd_growht-4.75))


**********************************************
*** Standardization of Continous Variables ***
**********************************************
*** Note: All standardized variables have the prefix zee_ 
norm age, method(zee)
norm poldiscuss, method(zee)
norm EPI_weighted, method(zee)
norm corruption, method(zee)
norm EU_budget_balance, method(zee)

**************************************************************
*** Multivariate Analysis (Table D in the Online Appendix) ***
**************************************************************

*** Null 5
meprobit trust_EU_Comm  ||  month: , covariance(unstructured)
outreg2 using "Table_D.ster", replace ctitle(NULL) dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
outreg2 using "Table_D.xls",  excel replace  ctitle(NULL1)  dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
estat ic
estat icc

*** Model 12
meprobit trust_EU_Comm zee_age male b3.education married i.unemployed  i.urban i.poldiscuss i.trust_government i.support_euro zee_EPI_weighted zee_corruption  zee_EU_budget_balance i.EU_election_year  ||  month: , covariance(unstructured)
outreg2 using "Table_D.ster", append ctitle(NULL) dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
outreg2 using "Table_D.xls",  excel append  ctitle(NULL1)  dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
estat ic
estat icc

*** Model 13
meprobit trust_EU_Comm zee_age male b3.education married i.unemployed  i.urban i.poldiscuss trust_government i.support_euro zee_EPI_weighted zee_corruption  zee_EU_budget_balance i.EU_election_year  ||  month: trust_government , covariance(unstructured)
outreg2 using "Table_D.ster", append ctitle(NULL) dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
outreg2 using "Table_D.xls",  excel append  ctitle(NULL1)  dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
estat ic
estat icc

*** Model 14
meprobit trust_EU_Comm zee_age male b3.education married i.unemployed  i.urban i.poldiscuss i.support_euro i.trust_government##c.zee_EPI_weighted i.trust_government c.zee_corruption  zee_EU_budget_balance i.EU_election_year  ||  month: trust_government , covariance(unstructured)
outreg2 using "Table_D.ster", append ctitle(NULL) dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
outreg2 using "Table_D.xls",  excel append  ctitle(NULL1)  dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
estat ic
estat icc

*** Model 15
meprobit trust_EU_Comm zee_age male b3.education married i.unemployed  i.urban i.poldiscuss i.support_euro c.zee_EPI_weighted i.trust_government##c.zee_corruption  zee_EU_budget_balance i.EU_election_year  ||  month: trust_government , covariance(unstructured)
outreg2 using "Table_D.ster", append ctitle(NULL) dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
outreg2 using "Table_D.xls",  excel append  ctitle(NULL1)  dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
estat ic
estat icc

*** Model 16
meprobit trust_EU_Comm zee_age male b3.education married i.unemployed  i.urban i.poldiscuss i.support_euro i.trust_government##c.zee_EPI_weighted i.trust_government##c.zee_corruption  zee_EU_budget_balance i.EU_election_year  ||  month: trust_government , covariance(unstructured)
outreg2 using "Table_D.ster", append ctitle(NULL) dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
outreg2 using "Table_D.xls",  excel append  ctitle(NULL1)  dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
estat ic
estat icc

*************************
*** Marginal Effects  ***
*************************
*** Notes: For better interpretation the marginal effects plots are based on unstandardized coefficients for government fractionalization.

*** Model 16: Individual Level + Contextual Level + Cross-Level Interaction (unstandardized coefficients)  
meprobit trust_EU_Comm zee_age male b3.education married i.unemployed  i.urban i.poldiscuss i.support_euro i.trust_government##c.EPI_weighted i.trust_government##c.corruption  zee_EU_budget_balance i.EU_election_year  ||  quarter: trust_government, covariance(unstructured)

margins, dydx(trust_government) at(EPI_weighted=(60 (5) 90)) predict(pr fixedonly) atmeans noatlegend vsquish
marginsplot, recast(line) recastci(rarea) yline(0)

margins, dydx(trust_government) at(corruption=(0 (5) 55)) predict(pr fixedonly) atmeans noatlegend vsquish
marginsplot, recast(line) recastci(rarea) yline(0)

********************************
*** Predicted Probabilities  ***
********************************
*** Model 12 (unstandardized coefficients)  
meprobit trust_EU_Comm age male b3.education married i.unemployed  i.urban i.poldiscuss i.support_euro i.trust_government c.EPI_weighted  corruption  EU_budget_balance i.EU_election_year  ||  quarter: , covariance(unstructured)

* Change in Probabilities from Min to Max
margins, at(age=(15 99)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish
margins, at(male=(0 1)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish
margins, at(education=(3 1)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish
margins, at(education=(3 2)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish
margins, at(education=(3 4)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish
margins, at(married=(0 1)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish
margins, at(urban=(0 1)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish
margins, at(unemployed=(0 1)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish
margins, at(poldiscuss=(0 1)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish
margins, at(poldiscuss=(0 2)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish
margins, at(support_euro=(0 1)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish
margins, at(trust_government=(0 1)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish
margins, at(EPI_weighted=(59.17618 92.25895)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish
margins, at(corruption=(.47 55.37)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish
margins, at(EU_budget_balance=(1090.6 8859.4)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish
margins, at(EU_election_year=(0 1)) predict(pr fixedonly) contrast(at effects) atmeans noatlegend vsquish

* Gen Matrix for coefplot
matrix trust_EC = (.0912563,.0423241,.1401885\-.0221573,-.0382752,-.0060394\-.077144,-.1011934,-.0530946\-.0325278,-.0544108,-.0106448\.0160375,-.0174266,.0495017\.008431,-.0092931,.0261551\-.0205516,-.0402326,-.0008707\-.0308223,-.0560136,-.0056309\.0630291,.0449861,.0810721\.039338,.0147125,.0639635\.3351095,.3180456,.3521735\.,.,.\.3807978,.3641782,.3974175\.2590404,.1510597,.367021\ -.3573429,-.4551078,-.2595779\-.0298409,-.1450335,.0853517\-.0107742,-.0836891,.0621406)
matrix rownames trust_EC = "Age" "Male" "Education (up to 15)" "Education (16-19)" "Education (Still studying)" "Married/ cohabitating" "Urban residency" "Unemployed" "Pol. discussion (occasionally)" "Pol. discussion (frequently)" "Support for Euro/ Monetary Union" "Trust in Spanish parliament" "Trust in Spanish government" "Economic Performance Index (EPI)" "Perception of corruption" "EU Operating budgetary balances" "European election"
matrix dir 
matrix list trust_EC 

* Grab other values from above
matrix trust_EP = (.0880994,.040682,.1355168 \-.0211231,-.0368128,-.0054334\-.0552405,-.078875,-.0316061\-.0168693,-.0382711,.0045325\.0285072,-.0036943,.0607087\.0060859,-.0111368,.0233085\.0011088,-.0181781,.0203957\-.0334208,-.0582759,-.0085656\.058578,.0410239,.0761321\.0350908,.010981,.0592007\.3369398,.3197419,.3541377\.4235318,.4060697,.4409939\.,.,.\.24364,.1299802,.3572997\-.3519817,-.4596285,-.2443349\.0245304,-.0937809,.1428417\.0040279,-.0707455,.0788013)
matrix rownames trust_EP = "Age" "Male" "Education (up to 15)" "Education (16-19)" "Education (Still studying)" "Married/ cohabitating" "Urban residency" "Unemployed" "Pol. discussion (occasionally)" "Pol. discussion (frequently)" "Support for Euro/ Monetary Union" "Trust in Spanish parliament" "Trust in Spanish government" "Economic Performance Index (EPI)" "Perception of corruption" "EU Operating budgetary balances" "European election"

* Gen a combined plot
coefplot (matrix(trust_EP[,1]), ci((trust_EP[,2] trust_EP[,3]))) (matrix(trust_EC[,1]), ci((trust_EC[,2] trust_EC[,3]))), xline(0) legend(order(2 "Trust in European Parliament" 4 "Trust in European Commission") rows(2))

*************************************************************************************************************
/////////////////////////////////////////////////////////////////////////////////////////////////////////////
*** Trust in Representative Institutions of the EU with Lagged Predictors (Table E in the Online Appendix ***
/////////////////////////////////////////////////////////////////////////////////////////////////////////////
*************************************************************************************************************

*** Load Eurobarometer Trend Data. Compare Table A in the Online Appendix.
use "Eurobarometer.dta", clear

**************************
*** Drop missing cases ***
**************************
*** Trust
drop if trust_EU_Comm==.
drop if trust_government==.
drop if trust_EU_Parl==.
drop if trust_parliament==.

*** Individual-level covariates
drop if age==.
drop if male==.
drop if education==.
drop if married==.
drop if unemployed==.
drop if poldiscuss==.
drop if urban==.
drop if support_euro==.

*** Aggregate-level covariates
drop if lag_unemployment_rate==.
drop if lag_inflation_rate==.
drop if lag_budget_deficit==.
drop if lag_gpd_growht==.
drop if lag_corruption==.
drop if lag_EU_budget_balance==.

************************
*** Generate Indices ***
************************
*** Generate Economic Performance Index (EPI). Compare the Online Appendix for technical description.
/*
*** To obtain the correct std. dev. for the calculation of the index, please run the following syntax: 
bysort quarter: gen counter_n= _n
keep if counter_n==1
sum lag_inflation_rate // Std. Dev.: 1.558511
sum lag_unemployment_rate  // Std. Dev.: 6.706978
sum lag_budget_deficit // Std. Dev.: 4.422482  
sum lag_gpd_growht // Std. Dev.: 2.313304
*/

gen lag_EPI = 100 - abs(lag_inflation_rate) - (lag_unemployment_rate-4.75) + lag_budget_deficit + (lag_gpd_growht-4.75)
gen stdevav = (1.558511   + 6.706978  + 4.422482 + 2.313304) / 4
gen W_infl = (1/1.427295)* stdevav
gen W_unemp = (1/6.706978)* stdevav
gen W_deficit = (1/4.422482)* stdevav
gen W_growth = (1/2.313304)* stdevav
gen lag_EPI_weighted = 100 - (W_infl*abs(lag_inflation)) - (W_unemp*(lag_unemployment_rate-4.75)) + (lag_budget_deficit*W_deficit) + (W_growth*(lag_gpd_growht-4.75))


*** Generate tust in representative institutions of the EU index
gen trust_EU_rep = .
replace trust_EU_rep = 1 if trust_EU_Comm==1 & trust_EU_Parl==1
replace trust_EU_rep = 0 if trust_EU_Comm==0 & trust_EU_Parl==1
replace trust_EU_rep = 0 if trust_EU_Comm==1 & trust_EU_Parl==0
replace trust_EU_rep = 0 if trust_EU_Comm==0 & trust_EU_Parl==0
tab trust_EU_rep

*** Generate tust in representative institutions (Spain) index 
gen trust_rep = 0
replace trust_rep = 1 if trust_government==1 & trust_parliament==1
tab trust_rep

**********************************************
*** Standardization of Continous Variables ***
**********************************************
*** Note: All standardized variables have the prefix zee_ 
norm age, method(zee)
norm poldiscuss, method(zee)
norm lag_EPI_weighted, method(zee)
norm lag_corruption, method(zee)
norm lag_EU_budget_balance, method(zee)

******************************************************
*** Multivariate Analysis (Economic Model)         ***
******************************************************
*** Null 6
meprobit trust_EU_rep  ||  month: , covariance(unstructured)
outreg2 using "Table_E.ster", replace ctitle(NULL) dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
outreg2 using "Table_E.xls",  excel replace  ctitle(NULL1)  dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
estat ic
estat icc

*** Model 17 
meprobit trust_EU_rep zee_age male b3.education married i.unemployed  i.urban i.poldiscuss i.trust_rep i.support_euro zee_lag_EPI_weighted zee_lag_corruption  zee_lag_EU_budget_balance i.lag_EU_election_year ||  month: , covariance(unstructured)
outreg2 using "Table_E.ster", append ctitle(Model 2) dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
outreg2 using "Table_E.xls",  excel append  ctitle(Model 2)  dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
estat ic
estat icc

*** Model 18
meprobit trust_EU_rep zee_age male b3.education married i.unemployed  i.urban i.poldiscuss i.trust_rep i.support_euro zee_lag_EPI_weighted zee_lag_corruption  zee_lag_EU_budget_balance i.lag_EU_election_year ||  month: trust_rep , covariance(unstructured)
outreg2 using "Table_E.ster", append ctitle(Model 2) dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
outreg2 using "Table_E.xls",  excel append  ctitle(Model 2)  dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
estat ic
estat icc

*** Model 19 
meprobit trust_EU_rep zee_age male b3.education married i.unemployed  i.urban i.poldiscuss i.support_euro i.trust_rep##c.zee_lag_EPI_weighted c.zee_lag_corruption zee_lag_EU_budget_balance i.lag_EU_election_year ||  month: trust_rep , covariance(unstructured)
outreg2 using "Table_E.ster", append ctitle(Model 2) dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
outreg2 using "Table_E.xls",  excel append  ctitle(Model 2)  dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
estat ic
estat icc

*** Model 20 
meprobit trust_EU_rep zee_age male b3.education married i.unemployed  i.urban i.poldiscuss i.support_euro c.zee_lag_EPI_weighted i.trust_rep##c.zee_lag_corruption zee_lag_EU_budget_balance i.lag_EU_election_year ||  month: trust_rep , covariance(unstructured)
outreg2 using "Table_E.ster", append ctitle(Model 2) dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
outreg2 using "Table_E.xls",  excel append  ctitle(Model 2)  dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
estat ic
estat icc

*** Model 21 
meprobit trust_EU_rep zee_age male b3.education married i.unemployed  i.urban i.poldiscuss i.support_euro i.trust_rep##c.zee_lag_EPI_weighted i.trust_rep##c.zee_lag_corruption zee_lag_EU_budget_balance i.lag_EU_election_year ||  month: trust_rep  , covariance(unstructured)
outreg2 using "Table_E.ster", append ctitle(Model 2) dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
outreg2 using "Table_E.xls",  excel append  ctitle(Model 2)  dec(2) onecol alpha(0.001,0.01,0.05,0.1) symbol(***,**,*,+)
estat ic
estat icc

***********************
///////////////////////
*** End of Analysis ***
///////////////////////
***********************
